Struct codize::List

source ·
pub struct List {
    pub separator: String,
    pub trailing: Trailing,
    /* private fields */
}
A list of code segments separated by a separator

Fields

separator: String

The separator between the items

trailing: Trailing

The trailing mode

Implementations

source

impl List

source

pub fn empty<TSep: ToString>(sep: TSep) -> Self

Create a new empty code list

source

pub fn new<TSep, TBody>(sep: TSep, body: TBody) -> Self
where TSep: ToString, TBody: IntoIterator, TBody::Item: Into<Code>,

Create a new code list

source

pub fn no_trail(self) -> Self

Create a new code list with no trailing separator

source

pub fn always_trail(self) -> Self

Create a new code list with trailing separator even if the list is in one line

source

pub fn inline_when(self, condition: fn(_: &List) -> bool) -> Self

Set a condition for displaying the block as one line

source

pub fn inlined(self) -> Self

Set the inline condition to be always true

source

pub fn never_inlined(self) -> Self

Set the inline condition to be always false

source

pub fn body(&self) -> &[Code]

Get the body of the block

source

pub fn is_empty(&self) -> bool

Get if the list will generate any code or not (empty = no code)

source

pub fn should_inline(&self) -> bool

Should the list be displayed in one line

source

pub fn should_inline_intrinsic(&self) -> bool

Should intrinsicly inline the list

This is used for lists that only contain one item